==> haskell-network-ip-0.3.0.2-60-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-Ka3GySQnVKn7BEPmUEDPCJ
key: network-ip-0.3.0.2-Ka3GySQnVKn7BEPmUEDPCJ
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: 058b3166697acbd00530f43a8a784daf
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-Ka3GySQnVKn7BEPmUEDPCJ
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek
    data-dword-0.3.1.2-GBBy3CkwOwDEpxaArISGTV
    type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    data-serializer-0.3.4-CqtfG0iycEG358x3jrkx19
    text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3
    data-textual-0.3.0.2-2un9yxcZJfOueBIkDP9zY
    parsers-0.12.9-HSuiRQJTKA09iCHUp4tatf
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek=d9939c686c8812f32033853596341c48
             data-dword-0.3.1.2-GBBy3CkwOwDEpxaArISGTV=4a03d1ceed420ec0af2795b860687a12
             type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V=a1690a073063048303d9dcd1b01fdf89
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             data-serializer-0.3.4-CqtfG0iycEG358x3jrkx19=965d84fbf136b633c247597070e34563
             text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3=611c3e6eaf60e47d7419aeb7344d21cd
             data-textual-0.3.0.2-2un9yxcZJfOueBIkDP9zY=729f6b5333ffb1a2071f94d3596dac2c
             parsers-0.12.9-HSuiRQJTKA09iCHUp4tatf=895f22145eb275fad8c9d5dd303ea874
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.2-61-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-Lt06ZzrcolKAI6fn8K1ZwC
key: network-ip-0.3.0.2-Lt06ZzrcolKAI6fn8K1ZwC
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: 4a36c3ff4920f3a5413ec7edbf9d4a6c
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-Lt06ZzrcolKAI6fn8K1ZwC
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek
    data-dword-0.3.1.2-GBBy3CkwOwDEpxaArISGTV
    type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    data-serializer-0.3.4-LvLWIoVzoDoAEWxzy2VxoC
    text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3
    data-textual-0.3.0.2-12LeL25xQjlKlKLOPpvjYN
    parsers-0.12.9-DuBQfXvlSLrIDPBeCtibof
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek=d9939c686c8812f32033853596341c48
             data-dword-0.3.1.2-GBBy3CkwOwDEpxaArISGTV=4a03d1ceed420ec0af2795b860687a12
             type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V=a1690a073063048303d9dcd1b01fdf89
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             data-serializer-0.3.4-LvLWIoVzoDoAEWxzy2VxoC=f16ebdcb88de92bbde1d463fb6bfcf40
             text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3=611c3e6eaf60e47d7419aeb7344d21cd
             data-textual-0.3.0.2-12LeL25xQjlKlKLOPpvjYN=b7867d993d0d081b41af2731aed65817
             parsers-0.12.9-DuBQfXvlSLrIDPBeCtibof=a3493c4d09dc6cbc5bb31cf8f02007af
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
